#!/usr/bin/env bash
#
# Configure Nginx configuration based on
# AWS Beanstalk Software Configuration.
# Application is located in /var/app/staging/
#
# Created: 2016-06-05 12:56 kim@infomaker.se
# Changed: 2019-04-09 14:35 kim@infomaker.se
# Changed: 2021-09-01 15:03 erik.johansson@navigaglobal.com

AWS_CONFIG_BIN="/opt/elasticbeanstalk/bin/get-config"
NGINX_CONFIG_PATH="/var/app/staging/nginx/standard/aws"

# Get values from the IM defaulted variables
NGX_WORKER_CONNECTIONS="$(${AWS_CONFIG_BIN} environment -k NGX_WORKER_CONNECTIONS)"
NGX_WORKER_PROCESSES="$(${AWS_CONFIG_BIN} environment -k NGX_WORKER_PROCESSES)"
REDIS_OB_HOST="$(${AWS_CONFIG_BIN} environment -k REDIS_OB_HOST)"

# Insert Nginx settings from Beanstalk.
if [[ ! -z ${NGX_WORKER_CONNECTIONS} && ! -z ${NGX_WORKER_PROCESSES} && -e ${NGINX_CONFIG_PATH}/nginx.conf ]]; then
  echo "Configuring Nginx"
  sed -i -e "s/^.*worker_processes.*/worker_processes ${NGX_WORKER_PROCESSES};/g" ${NGINX_CONFIG_PATH}/nginx.conf
  sed -i -e "s/^.*worker_connections.*/worker_connections ${NGX_WORKER_CONNECTIONS};/g" ${NGINX_CONFIG_PATH}/nginx.conf
fi
